==> pyalsi-0.4.5.1.tar.gz: pyalsi-0.4.5.1/pyalsi/logos.py <==
"""
This is where im storing the logo's
basically just a dict, with the key as the name
"""

logos = {'Arch': {
    'Archey':  # ASCII art by Brett Bohnenkamper <kittykatt@silverirc.com>
        """{c1}                          .                    XX
        {c1}                  #                    XX
        {c1}                 ###                   XX
        {c1}                #####                  XX
        {c1}                ######                 XX
        {c1}               ; #####;                XX
        {c1}              +##.#####                XX
        {c1}             +##########               XX
        {c1}            ######{c2}#####{c1}##;             XX
        {c1}           ###{c2}############{c1},            XX
        {c1}          #{c2}######   #######.           XX
        {c2}        .######;     ;###;`".          XX
        {c2}       .#######;     ;#####.           XX
        {c2}       #########.   .########`         XX
        {c2}      ######'           '######        XX
        {c2}     ;####                 ####;       XX
        {c2}     ##'                     '##       XX
        {c2}    #'                         `#      """,
    'Screenfetch':
        """{c1}                           `                        XX
        {c1}                  .o+`                      XX
        {c1}                 `ooo/                      XX
        {c1}                `+oooo:                     XX
        {c1}               `+oooooo:                    XX
        {c1}               -+oooooo+:                   XX
        {c1}             `/:-:++oooo+:                  XX
        {c1}            `/++++/+++++++:                 XX
        {c1}           `/++++++++++++++:                XX
        {c1}          `/+++o{c2}oooooooo{c1}oooo/`              XX
        {c1}         ./{c2}ooosssso++osssssso{c1}+`             XX
        {c2}        .oossssso-````/ossssss+`            XX
        {c2}       -osssssso.      :ssssssso.           XX
        {c2}      :osssssss/        osssso+++.          XX
        {c2}     /ossssssss/        +ssssooo/-`         XX
        {c2}   `/ossssso+/:-        -:/+osssso+-        XX
        {c2}  `+sso+:-`                 `.-/+oso:       XX
        {c2} `++:.                           `-/+/      XX
        {c2} .`                                 `+/     """,
    'Below':
        """
        {c2},{c1}                   _     _ _
   {c2}/{c1}#{c2}\\{c1}        __ _ _ __ ___| |__ | (_)_ __  _   ___  __
  {c2}/{c1}###{c2}\\{c1}      / _` | '__/ __| '_ \\| | | '_ \\| | | \\ \\/ /
 {c2}/{c1}#####{c2}\\{c1}    | (_| | | | (__| | | | | | | | | |_| |)  (
{c2}/{c1}##,-,##{c2}\\{c1}    \\__,_|_|  \\___|_| |_|_|_|_| |_|\\__,_/_/\\_\\
{c2}/{c1}##(   )##{c2}\\{c1}
{c2}/{c1}#.--   --.#{c2}\\   A simple, elegant GNU/Linux distribution.
{c2}/{c1}`           `{c2}\\"""},
    'Ubuntu': {
        'Archey':
            """                                            XX
{red}                          .oyhhs:           XX
{high}                 ..__.., {red}shhhhhh-           XX
{high}               -+++++++++'{red}:yyhhyo'          XX
{med}          .--  {high}-++++++++/-.-{red}::-'            XX
{med}        .::::-    {high}:----:/+++/++/.           XX
{med}       -:::::-.          {high}.:++++++:          XX
{high}  ,,, {med}.:::::-'             {high}.++++++-         XX
{high}./+++\-{med}'-::-                {high}./////:         XX
{high}+++++++ {med}.::-                                XX
{high}'\+++/-'{med}-::-                {red}:yyyyyo         XX
{high}  ''' '{med}-::::-              {red}:yhhhhh:         XX
{med}      -:::::-.           {red}-ohhhhhh+          XX
{med}       .::::-'  {red}-o+///+oyhhyyyhy:           XX
{med}        '.--   {red}/yhhhhhhhy+{med},....           XX
{red}               /hhhhhhhhh{med}-.-:::;            XX
{red}               '.:://::- {med}-:::::;            XX
{med}                         '.-:-'                """
    },
    'Debian': {
        'Below':
            """
{high}       _,###._       {c1}                              {c2}   ,#.
{high}     ,#########.     {c1}        ##:          :##       {c2} :###:
{high}   .######^######.   {c1}        ##'          `##      {c2}   `#'
{high}  .####'     `####   {c1}    __  ##     __     ##  __      _     __          _
{high}  ####' ,###. `###:  {c1}  ,####:##  ,######.  ##.#####. :### ,######. ###.####:
{high}  ###'  ##'`# ,###   {c1} ,##' `###  ##:  :##  ###' `###  ##' #:   `## `###' `##:
{high}  ###.  ###._,###'   {c1} ##    `##  ##    ##  ##'   `##  ##    ___,##  ##:   `##
{high}  `###  `######'     {c1} ##     ##  #######:  ##     ##  ##  .#######  ##'    ##
{high}   `###    `"'       {c1} ##     ##  ##'       ##     ##  ##  ##'  `##  ##     ##
{high}    `###.            {c1} ##.   ,##  ##        ##    ,##  ##  ##    ##  ##     ##
{high}      `###,          {c1} :#:._,###  ##:__,##  ##:__,##' ,##. ##.__:##. ##     ##
{high}        `"##:.       {c1} `:#### ###  ######'  `######'  #### `#####"## ##     ##
"""
    },
    'Fedora': {
        'Screenfetch':
            """                                         XX
{c1}          /:-------------:               XX
{c1}       :-------------------::            XX
{c1}     :-----------{c2}/shhOHbmp{c1}---:\\          XX
{c1}   /-----------{c2}omMMMNNNMMD{c1}  ---:         XX
{c1}  :-----------{c2}sMMMMNMNMP{c1}     ---:        XX
{c1} :-----------{c2}:MMMdp{c1}-----      ---:       XX
{c1},------------{c2}:MMMd{c1}------      ---:       XX
{c1}:------------{c2}:MMMd{c1}-----      .---:       XX
{c1}:----    {c2}oNMMMMMMMMMMho{c1}     .----:       XX
{c1}:--      {c2}+shhhMMMmhhy++{c1}   .------        XX
{c1}:-      -----{c2}:MMMd{c1}--------------:        XX
{c1}:-     ------{c2}/MMMd{c1}-------------;         XX
{c1}:-    {c2}..{c1}----{c2}/hMMMy{c1}------------:          XX
{c1}:-- {c2}:dMNdhhdNMMNo{c1}------------;           XX
{c1}:---{c2}:sdNMMMMNds:{c1}------------:            XX
{c1}:------{c2}:://:{c1}--------------::             XX
{c1}:----------------------://               XX
"""
    },
    'Apricity OS': {
        'Below':
            """

{c2}       ,
{c2}      ,#,
{c2}     ,###,
{c2}    ,##,##,  {c1}####,   {c1}<>    {c1}<>{c2} #
{c2}   ,##: :##, {c1}## ##          {c2}#####
{c2}  ,##L___J##,{c1}####:{c2}###,{c1}#{c2},###,{c1}# {c2}#  {c1}#  ##
{c2} ,##poooooq##,{c1}#  {c2}## ##{c1}#{c2}#   {c1}## {c2}# ,{c1}#, ##
{c2},##'       '##,{c1}  {c2}##  {c1}##{c2}'###'{c1}# {c2}'#'{c1}'####
                            {c1}{c2}{c1}{c2}{c1}{c1}{c1}{c1}. ,##
                            {c1}{c2}{c1}{c2}{c1}{c1}{c1}{c1}'###'
"""
    }}

==> pyalsi-0.5.3.tar.gz: pyalsi-0.5.3/pyalsi/logos.py <==
"""
This is where im storing the logo's
basically just a dict, with the key as the name
"""

logos = {'Arch': {
    'Archey':  # ASCII art by Brett Bohnenkamper <kittykatt@silverirc.com>
        """                                               XX
        {c1}                  .                    XX
        {c1}                  #                    XX
        {c1}                 ###                   XX
        {c1}                #####                  XX
        {c1}                ######                 XX
        {c1}               ; #####;                XX
        {c1}              +##.#####                XX
        {c1}             +##########               XX
        {c1}            ######{c2}#####{c1}##;             XX
        {c1}           ###{c2}############{c1},            XX
        {c1}          #{c2}######   #######.           XX
        {c2}        .######;     ;###;`".          XX
        {c2}       .#######;     ;#####.           XX
        {c2}       #########.   .########`         XX
        {c2}      ######'           '######        XX
        {c2}     ;####                 ####;       XX
        {c2}     ##'                     '##       XX
        {c2}    #'                         `#      """,
    'Screenfetch': """                                                    XX
        {c1}                   `                        XX
        {c1}                  .o+`                      XX
        {c1}                 `ooo/                      XX
        {c1}                `+oooo:                     XX
        {c1}               `+oooooo:                    XX
        {c1}               -+oooooo+:                   XX
        {c1}             `/:-:++oooo+:                  XX
        {c1}            `/++++/+++++++:                 XX
        {c1}           `/++++++++++++++:                XX
        {c1}          `/+++o{c2}oooooooo{c1}oooo/`              XX
        {c1}         ./{c2}ooosssso++osssssso{c1}+`             XX
        {c2}        .oossssso-````/ossssss+`            XX
        {c2}       -osssssso.      :ssssssso.           XX
        {c2}      :osssssss/        osssso+++.          XX
        {c2}     /ossssssss/        +ssssooo/-`         XX
        {c2}   `/ossssso+/:-        -:/+osssso+-        XX
        {c2}  `+sso+:-`                 `.-/+oso:       XX
        {c2} `++:.                           `-/+/      XX
        {c2} .`                                 `+/     """,
    'Below': """
    {c2}   ,{c1}                       _     _ _
   {c2}   /{c1}#{c2}\\{c1}        __ _ _ __ ___| |__ | (_)_ __  _   ___  __
  {c2}   /{c1}###{c2}\\{c1}      / _` | '__/ __| '_ \\| | | '_ \\| | | \\ \\/ /
 {c2}   /{c1}#####{c2}\\{c1}    | (_| | | | (__| | | | | | | | | |_| |)  (
{c2}   /{c1}##,-,##{c2}\\{c1}    \\__,_|_|  \\___|_| |_|_|_|_| |_|\\__,_/_/\\_\\
{c2}  /{c1}##(   )##{c2}\\{c1}
{c2} /{c1}#.--   --.#{c2}\\        A simple, elegant GNU/Linux distribution.
{c2}/{c1}`           `{c2}\\"""},
    'Ubuntu': {
        'Archey': """                                            XX
{red}                          .oyhhs:           XX
{high}                 ..__.., {red}shhhhhh-           XX
{high}               -+++++++++'{red}:yyhhyo'          XX
{med}          .--  {high}-++++++++/-.-{red}::-'            XX
{med}        .::::-    {high}:----:/+++/++/.           XX
{med}       -:::::-.          {high}.:++++++:          XX
{high}  ,,, {med}.:::::-'             {high}.++++++-         XX
{high}./+++\-{med}'-::-                {high}./////:         XX
{high}+++++++ {med}.::-                                XX
{high}'\+++/-'{med}-::-                {red}:yyyyyo         XX
{high}  ''' '{med}-::::-              {red}:yhhhhh:         XX
{med}      -:::::-.           {red}-ohhhhhh+          XX
{med}       .::::-'  {red}-o+///+oyhhyyyhy:           XX
{med}        '.--   {red}/yhhhhhhhy+{med},....             XX
{red}               /hhhhhhhhh{med}-.-:::;            XX
{red}               '.:://::- {med}-:::::;            XX
{med}                         '.-:-'                """
    },
    'Debian': {
        'Below':
            """
{high}       _,###._       {c1}                              {c2}   ,#.
{high}     ,#########.     {c1}        ##:          :##       {c2} :###:
{high}   .######^######.   {c1}        ##'          `##      {c2}   `#'
{high}  .####'     `####   {c1}    __  ##     __     ##  __      _     __          _
{high}  ####' ,###. `###:  {c1}  ,####:##  ,######.  ##.#####. :### ,######. ###.####:
{high}  ###'  ##'`# ,###   {c1} ,##' `###  ##:  :##  ###' `###  ##' #:   `## `###' `##:
{high}  ###.  ###._,###'   {c1} ##    `##  ##    ##  ##'   `##  ##    ___,##  ##:   `##
{high}  `###  `######'     {c1} ##     ##  #######:  ##     ##  ##  .#######  ##'    ##
{high}   `###    `"'       {c1} ##     ##  ##'       ##     ##  ##  ##'  `##  ##     ##
{high}    `###.            {c1} ##.   ,##  ##        ##    ,##  ##  ##    ##  ##     ##
{high}      `###,          {c1} :#:._,###  ##:__,##  ##:__,##' ,##. ##.__:##. ##     ##
{high}        `"##:.       {c1} `:#### ###  ######'  `######'  #### `#####"## ##     ##
"""
    },
    'Fedora': {
        'Screenfetch':
            """                                         XX
{c1}          /:-------------:               XX
{c1}       :-------------------::            XX
{c1}     :-----------{c2}/shhOHbmp{c1}---:\\          XX
{c1}   /-----------{c2}omMMMNNNMMD{c1}  ---:         XX
{c1}  :-----------{c2}sMMMMNMNMP{c1}     ---:        XX
{c1} :-----------{c2}:MMMdp{c1}-----      ---:       XX
{c1},------------{c2}:MMMd{c1}------      ---:       XX
{c1}:------------{c2}:MMMd{c1}-----      .---:       XX
{c1}:----    {c2}oNMMMMMMMMMMho{c1}     .----:       XX
{c1}:--      {c2}+shhhMMMmhhy++{c1}   .------        XX
{c1}:-      -----{c2}:MMMd{c1}--------------:        XX
{c1}:-     ------{c2}/MMMd{c1}-------------;         XX
{c1}:-    {c2}..{c1}----{c2}/hMMMy{c1}------------:          XX
{c1}:-- {c2}:dMNdhhdNMMNo{c1}------------;           XX
{c1}:---{c2}:sdNMMMMNds:{c1}------------:            XX
{c1}:------{c2}:://:{c1}--------------::             XX
{c1}:----------------------://               XX
"""
    },
    'Apricity OS': {
        'Below':
            """

{c2}       ,
{c2}      ,#,
{c2}     ,###,
{c2}    ,##,##,  {c1}####,   {c1}<>    {c1}<>{c2} #
{c2}   ,##: :##, {c1}## ##          {c2}#####
{c2}  ,##L___J##,{c1}####:{c2}###,{c1}#{c2},###,{c1}# {c2}#  {c1}#  ##
{c2} ,##poooooq##,{c1}#  {c2}## ##{c1}#{c2}#   {c1}## {c2}# ,{c1}#, ##
{c2},##'       '##,{c1}  {c2}##  {c1}##{c2}'###'{c1}# {c2}'#'{c1}'####
                            {c1}{c2}{c1}{c2}{c1}{c1}{c1}{c1}. ,##
                            {c1}{c2}{c1}{c2}{c1}{c1}{c1}{c1}'###'
"""
    }}
logos['Antergos Linux'] = logos['Arch']
